@@ -1,19 +1,25 @@
 import os
 import subprocess
 from pyngrok import ngrok
+
 try:
     from google.colab import drive
+
     colab_env = True
 except ImportError:
     colab_env = False
 
 
+EXTENSIONS = ["ms-python.python", "jithurjacob.nbpreviewer"]
+
+
 class ColabCode:
-    def __init__(self, port=10000, password=None, gcloud=False):
+    def __init__(self, port=10000, password=None, mount_drive=False):
         self.port = port
         self.password = password
-        self._mount = gcloud
+        self._mount = mount_drive
         self._install_code()
+        self._install_extensions()
         self._start_server()
         self._run_code()
 
@@ -23,6 +29,10 @@ class ColabCode:
         )
         subprocess.run(["sh", "install.sh"], stdout=subprocess.PIPE)
 
+    def _install_extensions(self):
+        for ext in EXTENSIONS:
+            subprocess.run(["code-server", "--install-extension", f"{ext}"])
+
     def _start_server(self):
         active_tunnels = ngrok.get_tunnels()
         for tunnel in active_tunnels:
